User Guide
==========

In the sections below you can learn how to define and write a DLIS file using the ``dlis-writer``.
The last page mentions some known issues when using different DLIS viewers and possible solutions to these.


.. toctree::
   :maxdepth: 1

   minimalexample
   extendingmetadata
   addingmoreobjects
   enums
   compatibilityissues
